@@ -1,4 +1,7 @@
 class Config:
+    class Default:
+        taskfolder = 'tasks'
+
     """
     Service Config as Singleton
     """
@@ -8,9 +11,9 @@ class Config:
 
     def __new__(cls):
         if cls._instance is None:
-            print('Creating the object')
+            print('Creatin the object')
             cls._instance = super(Config, cls).__new__(cls)
-            # Put any initialization here.
+            cls._instance.cmd_args = Config.Default()
         return cls._instance
 
     @property
